@@ -3,18 +3,14 @@ This module descibes how to build your own prediction algorithm. Please refer
 to User Guide for more insight.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import numpy as np
 
-from surprise import AlgoBase
-from surprise import Dataset
+from surprise import AlgoBase, Dataset
 from surprise.model_selection import cross_validate
 
 
 class MyOwnAlgorithm(AlgoBase):
-
     def __init__(self):
 
         # Always call base method before doing anything.
@@ -35,7 +31,7 @@ class MyOwnAlgorithm(AlgoBase):
         return sum_means / div
 
 
-data = Dataset.load_builtin('ml-100k')
+data = Dataset.load_builtin("ml-100k")
 algo = MyOwnAlgorithm()
 
 cross_validate(algo, data, verbose=True)
