@@ -2,20 +2,16 @@
 This module describes how to use the train_test_split() function.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
-from surprise import SVD
-from surprise import Dataset
-from surprise import accuracy
+from surprise import accuracy, Dataset, SVD
 from surprise.model_selection import train_test_split
 
 # Load the movielens-100k dataset (download it if needed),
-data = Dataset.load_builtin('ml-100k')
+data = Dataset.load_builtin("ml-100k")
 
 # sample random trainset and testset
 # test set is made of 25% of the ratings.
-trainset, testset = train_test_split(data, test_size=.25)
+trainset, testset = train_test_split(data, test_size=0.25)
 
 # We'll use the famous SVD algorithm.
 algo = SVD()
